#
# Author:: Daniel DeLeo (<dan@kallistec.com>)
# Copyright:: Copyright (c) 2009 Daniel DeLeo
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require 'spec_helper'
require 'support/shared/unit/resource/static_provider_resolution'

describe Chef::Resource::DeployRevision do

  static_provider_resolution(
    resource: Chef::Resource::DeployRevision,
    provider: Chef::Provider::Deploy::Revision,
    name: :deploy_revision,
    action: :deploy,
  )

end

describe Chef::Resource::DeployBranch do

  static_provider_resolution(
    resource: Chef::Resource::DeployBranch,
    provider: Chef::Provider::Deploy::Revision,
    name: :deploy_branch,
    action: :deploy,
  )

end
